==> js-2.0.tar.gz: js-2.0/_sym.h <==
/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
#ifndef _SYM_H_
#define _SYM_H_

#define K_do          0x0000326F
#define K_if          0x000034E6
#define K_in          0x000034EE
#define K_M_E         0x00136FC5
#define K_NAN         0x0013A0CE
#define K_abs         0x00187173
#define K_cos         0x0018F7F3
#define K_exp         0x00197C70
#define K_for         0x0019B7F2
#define K_log         0x001B37E7
#define K_max         0x001B70F8
#define K_md5         0x001B7235
#define K_min         0x001B74EE
#define K_new         0x001BB2F7
#define K_pop         0x001C37F0
#define K_pow         0x001C37F7
#define K_sin         0x001CF4EE
#define K_tan         0x001D30EE
#define K_try         0x001D3979
#define K_var         0x001DB0F2
#define K_M_PI        0x09B7E849
#define K_acos        0x0C38F7F3
#define K_asin        0x0C3CF4EE
#define K_atan        0x0C3D30EE
#define K_case        0x0C7879E5
#define K_ceil        0x0C7974EC
#define K_date        0x0C987A65
#define K_echo        0x0CB8F46F
#define K_else        0x0CBB39E5
#define K_eval        0x0CBDB0EC
#define K_exit        0x0CBE34F4
#define K_tmpfile     0x0CD9D0BB
#define K_fgid        0x0CD9F4E4
#define K_fuid        0x0CDD74E4
#define K_getc        0x0CF97A63
#define K_gets        0x0CF97A73
#define K_glob        0x0CFB37E2
#define K_goto        0x0CFBFA6F
#define K_join        0x0D5BF4EE
#define K_keys        0x0D797CF3
#define K_splice      0x0D9A76DB
#define K_replace     0x0D9BE7BB
#define K_load        0x0D9BF0E4
#define K_null        0x0DDD766C
#define K_popen       0x0DFC32E0
#define K_pack        0x0E1871EB
#define K_push        0x0E1D79E8
#define K_putc        0x0E1D7A63
#define K_puts        0x0E1D7A73
#define K_rand        0x0E587764
#define K_read        0x0E5970E4
#define K_print       0x0E5A777A
#define K_seek        0x0E7972EB
#define K_sort        0x0E7BF974
#define K_sqrt        0x0E7C7974
#define K_tell        0x0E99766C
#define K_this        0x0E9A34F3
#define K_time        0x0E9A76E5
#define K_trim        0x0E9CB4ED
#define K_true        0x0E9CBAE5
#define K_void        0x0EDBF4E4
#define K___LINE__    0x18AF9316
#define K___FILE__    0x18EF93B6
#define K_INFINITY    0x18F41E30
#define K_isfinite    0x1C7DE408
#define K_values      0x1D9D759F
#define K_index       0x1DD932F5
#define K_rindex      0x1DD935D5
#define K_println     0x1DDEB143
#define K_typeof      0x1E1970A9
#define K_isArray     0x1E5FFFC1
#define K_isInt       0x1E727779
#define K_isinf       0x1E7A776B
#define K_isnan       0x1E7BB0E3
#define K_system      0x1E7D35D2
#define K_atan2       0x1E98773E
#define K_fatime      0x1E9A7089
#define K_unquote     0x1EB8548B
#define K_quote       0x1EBBFA6B
#define K_M_2_SQRTPI  0x249FD5E8
#define K_jconv       0x2C7BF77B
#define K_foreach     0x2CBB4716
#define K_isObject    0x2CFEED08
#define K_printfile   0x2D11388A
#define K_sprintf     0x2D382568
#define K_printf      0x2D3BBD68
#define K_dbopen      0x2DFC34A2
#define K_round       0x2DFD776A
#define K_break       0x2E5970E7
#define K_M_SQRT1_2   0x31F2F2A9
#define K_writefile   0x33113928
#define K_isBool      0x385BF172
#define K_isChar      0x387A366C
#define K_isNull      0x39DD70F2
#define K_M_SQRT2     0x3A36C7C8
#define K_catch       0x3C3D31E4
#define K_chdir       0x3D1934FE
#define K_unshift     0x3D19DD9A
#define K_shift       0x3D1A737A
#define K_chmod       0x3D1B77E8
#define K_chown       0x3D1BFBE2
#define K_class       0x3D9879FF
#define K_close       0x3D9BF9E9
#define K_pclose      0x3D9BFEE9
#define K_split       0x3E1B34FA
#define K_crypt       0x3E5E7878
#define K_fctime      0x3E9A7089
#define K_function    0x3F01D902
#define K_M_LOG2E     0x49F3B4BC
#define K_label       0x4C38B2E1
#define K_continue    0x4CB4C40B
#define K_readfile    0x4D115879
#define K_throw       0x4D1CB7F9
#define K_toInt       0x4DF2777A
#define K_log10       0x4DF9D8BD
#define K_touch       0x4DFD71E6
#define K_trace       0x4E5871EB
#define K_untrace     0x4E5BDF0B
#define K_toString    0x4F890A59
#define K_isString    0x4FFDEA59
#define K_M_LN2       0x5BF3273B
#define K_isNumber    0x5C1F2E1C
#define K_match       0x5C3D31E5
#define K_substr      0x5C5CFD4C
#define K_toNumber    0x5C6BCE1C
#define K_decode      0x5C7BF429
#define K_gmdate      0x5C987C18
#define K_mkdir       0x5D7934FF
#define K_delete      0x5D997C29
#define K_symlink     0x5D99E8F6
#define K_remove      0x5DBBFC49
#define K_rename      0x5DD871C9
#define K_length      0x5DD9FCA4
#define K_tempnam     0x5E1816B0
#define K_serial      0x5E5A77D0
#define K_getcwd      0x5E98FD98
#define K_setenv      0x5E99704A
#define K_getenv      0x5E99710A
#define K_fmtime      0x5E9A7088
#define K_gmtime      0x5E9A7098
#define K_return      0x5E9D7E42
#define K_rewind      0x5EFA7048
#define K_unserial    0x5F8D07D0
#define K_false       0x6C3B39E9
#define K_default     0x6C3E5028
#define K_encode      0x6C7BF438
#define K_fcopy       0x6C7BF875
#define K_reverse     0x6CBF2FBB
#define K_toFloat     0x6D98560C
#define K_isFloat     0x6D98BFCC
#define K_unlink      0x6D9A7036
#define K_flink       0x6D9A7767
#define K_floor       0x6D9BF7FE
#define K_truncate    0x6DABED38
#define K_fmode       0x6DBBF269
#define K_fopen       0x6DFC32E2
#define K_unpack      0x6E1876B6
#define K_fsize       0x6E7A7D69
#define K_M_1_PI      0x7637EC92
#define K_M_2_PI      0x7657EC92
#define K_toBool      0x785BF0A1
#define K_toChar      0x787A37BF
#define K_M_LN10      0x79939C6B
#define K_M_LOG10E    0x79DAA48C
#define K_M_PI_2      0x7A126B69
#define K_M_PI_4      0x7A126B6F
#define K_while       0x7D1A766B
#define K_switch      0x7D3D36D6
#define K_write       0x7E5A7A6B

#endif /* _SYM_H_ */

==> js3.0.1.tar.gz: js3.0.1/_sym.h <==
/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
#ifndef _SYM_H_
#define _SYM_H_

#define K_do          0x0000326F
#define K_if          0x000034E6
#define K_in          0x000034EE
#define K_M_E         0x00136FC5
#define K_NAN         0x0013A0CE
#define K_abs         0x00187173
#define K_cos         0x0018F7F3
#define K_exp         0x00197C70
#define K_for         0x0019B7F2
#define K_log         0x001B37E7
#define K_max         0x001B70F8
#define K_md5         0x001B7235
#define K_min         0x001B74EE
#define K_new         0x001BB2F7
#define K_pop         0x001C37F0
#define K_pow         0x001C37F7
#define K_sin         0x001CF4EE
#define K_sum         0x001CFAED
#define K_tan         0x001D30EE
#define K_try         0x001D3979
#define K_var         0x001DB0F2
#define K_M_PI        0x09B7E849
#define K_acos        0x0C38F7F3
#define K_asin        0x0C3CF4EE
#define K_atan        0x0C3D30EE
#define K_case        0x0C7879E5
#define K_ceil        0x0C7974EC
#define K_date        0x0C987A65
#define K_echo        0x0CB8F46F
#define K_else        0x0CBB39E5
#define K_eval        0x0CBDB0EC
#define K_exit        0x0CBE34F4
#define K_tmpfile     0x0CD9D0BB
#define K_fgid        0x0CD9F4E4
#define K_fuid        0x0CDD74E4
#define K_getc        0x0CF97A63
#define K_gets        0x0CF97A73
#define K_glob        0x0CFB37E2
#define K_goto        0x0CFBFA6F
#define K_join        0x0D5BF4EE
#define K_keys        0x0D797CF3
#define K_splice      0x0D9A76DB
#define K_replace     0x0D9BE7BB
#define K_load        0x0D9BF0E4
#define K_null        0x0DDD766C
#define K_popen       0x0DFC32E0
#define K_pack        0x0E1871EB
#define K_push        0x0E1D79E8
#define K_putc        0x0E1D7A63
#define K_puts        0x0E1D7A73
#define K_rand        0x0E587764
#define K_read        0x0E5970E4
#define K_print       0x0E5A777A
#define K_seek        0x0E7972EB
#define K_sort        0x0E7BF974
#define K_sqrt        0x0E7C7974
#define K_tell        0x0E99766C
#define K_this        0x0E9A34F3
#define K_time        0x0E9A76E5
#define K_trim        0x0E9CB4ED
#define K_true        0x0E9CBAE5
#define K_void        0x0EDBF4E4
#define K___LINE__    0x18AF9316
#define K___FILE__    0x18EF93B6
#define K_INFINITY    0x18F41E30
#define K_isfinite    0x1C7DE408
#define K_values      0x1D9D759F
#define K_timegm      0x1DB974A0
#define K_index       0x1DD932F5
#define K_rindex      0x1DD935D5
#define K_println     0x1DDEB143
#define K_typeof      0x1E1970A9
#define K_isArray     0x1E5FFFC1
#define K_isInt       0x1E727779
#define K_isinf       0x1E7A776B
#define K_isnan       0x1E7BB0E3
#define K_system      0x1E7D35D2
#define K_atan2       0x1E98773E
#define K_fatime      0x1E9A7089
#define K_unquote     0x1EB8548B
#define K_quote       0x1EBBFA6B
#define K_M_2_SQRTPI  0x249FD5E8
#define K_tracef      0x2C38F5A8
#define K_traces      0x2C38F5BD
#define K_jconv       0x2C7BF77B
#define K_foreach     0x2CBB4716
#define K_isObject    0x2CFEED08
#define K_printfile   0x2D11388A
#define K_sprintf     0x2D382568
#define K_printf      0x2D3BBD68
#define K_formats     0x2DBB4C8D
#define K_formatf     0x2DBB4C98
#define K_dbopen      0x2DFC34A2
#define K_round       0x2DFD776A
#define K_break       0x2E5970E7
#define K_M_SQRT1_2   0x31F2F2A9
#define K_writefile   0x33113928
#define K_isBool      0x385BF172
#define K_isChar      0x387A366C
#define K_isNull      0x39DD70F2
#define K_M_SQRT2     0x3A36C7C8
#define K_catch       0x3C3D31E4
#define K_chdir       0x3D1934FE
#define K_unshift     0x3D19DD9A
#define K_shift       0x3D1A737A
#define K_chmod       0x3D1B77E8
#define K_chown       0x3D1BFBE2
#define K_class       0x3D9879FF
#define K_close       0x3D9BF9E9
#define K_pclose      0x3D9BFEE9
#define K_count       0x3DFD7778
#define K_split       0x3E1B34FA
#define K_crypt       0x3E5E7878
#define K_stdin       0x3E9934E0
#define K_mktime      0x3E9A7038
#define K_fctime      0x3E9A7089
#define K_function    0x3F01D902
#define K_M_LOG2E     0x49F3B4BC
#define K_label       0x4C38B2E1
#define K_stderr      0x4C997E4C
#define K_stdout      0x4C9BFDCA
#define K_continue    0x4CB4C40B
#define K_readfile    0x4D115879
#define K_throw       0x4D1CB7F9
#define K_toInt       0x4DF2777A
#define K_log10       0x4DF9D8BD
#define K_touch       0x4DFD71E6
#define K_xmlopen     0x4DFFF433
#define K_trace       0x4E5871EB
#define K_untrace     0x4E5BDF0B
#define K_toString    0x4F890A59
#define K_isString    0x4FFDEA59
#define K_M_LN2       0x5BF3273B
#define K_isNumber    0x5C1F2E1C
#define K_match       0x5C3D31E5
#define K_substr      0x5C5CFD4C
#define K_toNumber    0x5C6BCE1C
#define K_decode      0x5C7BF429
#define K_gmdate      0x5C987C18
#define K_mkdir       0x5D7934FF
#define K_select      0x5D9976C8
#define K_delete      0x5D997C29
#define K_symlink     0x5D99E8F6
#define K_remove      0x5DBBFC49
#define K_rename      0x5DD871C9
#define K_length      0x5DD9FCA4
#define K_repmatch    0x5DF61EE5
#define K_tempnam     0x5E1816B0
#define K_serial      0x5E5A77D0
#define K_getcwd      0x5E98FD98
#define K_setenv      0x5E99704A
#define K_getenv      0x5E99710A
#define K_fmtime      0x5E9A7088
#define K_return      0x5E9D7E42
#define K_rewind      0x5EFA7048
#define K_unserial    0x5F8D07D0
#define K_false       0x6C3B39E9
#define K_default     0x6C3E5028
#define K_encode      0x6C7BF438
#define K_fcopy       0x6C7BF875
#define K_fetch       0x6CBD31E4
#define K_reverse     0x6CBF2FBB
#define K_toFloat     0x6D98560C
#define K_isFloat     0x6D98BFCC
#define K_unlink      0x6D9A7036
#define K_flink       0x6D9A7767
#define K_floor       0x6D9BF7FE
#define K_truncate    0x6DABED38
#define K_fmode       0x6DBBF269
#define K_fopen       0x6DFC32E2
#define K_unpack      0x6E1876B6
#define K_fsize       0x6E7A7D69
#define K_entity      0x6E9A7C24
#define K_unentity    0x6F4D0C24
#define K_M_1_PI      0x7637EC92
#define K_M_2_PI      0x7657EC92
#define K_toBool      0x785BF0A1
#define K_toChar      0x787A37BF
#define K_M_LN10      0x79939C6B
#define K_M_LOG10E    0x79DAA48C
#define K_M_PI_2      0x7A126B69
#define K_M_PI_4      0x7A126B6F
#define K_modify      0x7C9A75A4
#define K_while       0x7D1A766B
#define K_switch      0x7D3D36D6
#define K_write       0x7E5A7A6B

#endif /* _SYM_H_ */
